You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@aurora.apache.org by wf...@apache.org on 2013/12/31 22:28:07 UTC

[6/9] Refactors java and python code to the Apache namespace.

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/java/org/apache/aurora/scheduler/storage/log/LogManager.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/aurora/scheduler/storage/log/LogManager.java b/src/main/java/org/apache/aurora/scheduler/storage/log/LogManager.java
index da29401..9710e28 100644
--- a/src/main/java/org/apache/aurora/scheduler/storage/log/LogManager.java
+++ b/src/main/java/org/apache/aurora/scheduler/storage/log/LogManager.java
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.twitter.aurora.scheduler.storage.log;
+package org.apache.aurora.scheduler.storage.log;
 
 import java.io.IOException;
 import java.lang.annotation.ElementType;
@@ -42,26 +42,6 @@ import com.google.common.collect.Maps;
 import com.google.common.primitives.Bytes;
 import com.google.inject.BindingAnnotation;
 
-import com.twitter.aurora.codec.ThriftBinaryCodec.CodingException;
-import com.twitter.aurora.gen.ScheduledTask;
-import com.twitter.aurora.gen.storage.Frame;
-import com.twitter.aurora.gen.storage.FrameChunk;
-import com.twitter.aurora.gen.storage.FrameHeader;
-import com.twitter.aurora.gen.storage.LogEntry;
-import com.twitter.aurora.gen.storage.LogEntry._Fields;
-import com.twitter.aurora.gen.storage.Op;
-import com.twitter.aurora.gen.storage.RemoveTasks;
-import com.twitter.aurora.gen.storage.SaveHostAttributes;
-import com.twitter.aurora.gen.storage.SaveTasks;
-import com.twitter.aurora.gen.storage.Snapshot;
-import com.twitter.aurora.gen.storage.Transaction;
-import com.twitter.aurora.gen.storage.storageConstants;
-import com.twitter.aurora.scheduler.log.Log;
-import com.twitter.aurora.scheduler.log.Log.Entry;
-import com.twitter.aurora.scheduler.log.Log.Position;
-import com.twitter.aurora.scheduler.log.Log.Stream;
-import com.twitter.aurora.scheduler.log.Log.Stream.InvalidPositionException;
-import com.twitter.aurora.scheduler.log.Log.Stream.StreamAccessException;
 import com.twitter.common.application.ShutdownRegistry;
 import com.twitter.common.base.Closure;
 import com.twitter.common.base.ExceptionalCommand;
@@ -70,6 +50,27 @@ import com.twitter.common.quantity.Amount;
 import com.twitter.common.quantity.Data;
 import com.twitter.common.stats.Stats;
 
+import org.apache.aurora.codec.ThriftBinaryCodec.CodingException;
+import org.apache.aurora.gen.ScheduledTask;
+import org.apache.aurora.gen.storage.Frame;
+import org.apache.aurora.gen.storage.FrameChunk;
+import org.apache.aurora.gen.storage.FrameHeader;
+import org.apache.aurora.gen.storage.LogEntry;
+import org.apache.aurora.gen.storage.LogEntry._Fields;
+import org.apache.aurora.gen.storage.Op;
+import org.apache.aurora.gen.storage.RemoveTasks;
+import org.apache.aurora.gen.storage.SaveHostAttributes;
+import org.apache.aurora.gen.storage.SaveTasks;
+import org.apache.aurora.gen.storage.Snapshot;
+import org.apache.aurora.gen.storage.Transaction;
+import org.apache.aurora.gen.storage.storageConstants;
+import org.apache.aurora.scheduler.log.Log;
+import org.apache.aurora.scheduler.log.Log.Entry;
+import org.apache.aurora.scheduler.log.Log.Position;
+import org.apache.aurora.scheduler.log.Log.Stream;
+import org.apache.aurora.scheduler.log.Log.Stream.InvalidPositionException;
+import org.apache.aurora.scheduler.log.Log.Stream.StreamAccessException;
+
 import static com.google.common.base.Preconditions.checkNotNull;
 
 /**
@@ -134,7 +135,7 @@ public final class LogManager {
    * {@link #readFromBeginning(com.twitter.common.base.Closure) read from} the beginning,
    * a {@link #startTransaction() transaction} consisting of one or more local storage
    * operations can be committed atomically, or the log can be compacted by
-   * {@link #snapshot(com.twitter.aurora.gen.storage.Snapshot) snapshotting}.
+   * {@link #snapshot(org.apache.aurora.gen.storage.Snapshot) snapshotting}.
    */
   public static class StreamManager {
 

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/java/org/apache/aurora/scheduler/storage/log/LogStorage.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/aurora/scheduler/storage/log/LogStorage.java b/src/main/java/org/apache/aurora/scheduler/storage/log/LogStorage.java
index 74f06aa..82846c2 100644
--- a/src/main/java/org/apache/aurora/scheduler/storage/log/LogStorage.java
+++ b/src/main/java/org/apache/aurora/scheduler/storage/log/LogStorage.java
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.twitter.aurora.scheduler.storage.log;
+package org.apache.aurora.scheduler.storage.log;
 
 import java.io.IOException;
 import java.lang.annotation.ElementType;
@@ -39,48 +39,6 @@ import com.google.common.collect.ImmutableSet;
 import com.google.common.collect.Maps;
 import com.google.inject.BindingAnnotation;
 
-import com.twitter.aurora.codec.ThriftBinaryCodec.CodingException;
-import com.twitter.aurora.gen.HostAttributes;
-import com.twitter.aurora.gen.MaintenanceMode;
-import com.twitter.aurora.gen.storage.LogEntry;
-import com.twitter.aurora.gen.storage.Op;
-import com.twitter.aurora.gen.storage.RemoveJob;
-import com.twitter.aurora.gen.storage.RemoveLock;
-import com.twitter.aurora.gen.storage.RemoveQuota;
-import com.twitter.aurora.gen.storage.RemoveTasks;
-import com.twitter.aurora.gen.storage.RewriteTask;
-import com.twitter.aurora.gen.storage.SaveAcceptedJob;
-import com.twitter.aurora.gen.storage.SaveFrameworkId;
-import com.twitter.aurora.gen.storage.SaveHostAttributes;
-import com.twitter.aurora.gen.storage.SaveLock;
-import com.twitter.aurora.gen.storage.SaveQuota;
-import com.twitter.aurora.gen.storage.SaveTasks;
-import com.twitter.aurora.gen.storage.Snapshot;
-import com.twitter.aurora.scheduler.base.Query;
-import com.twitter.aurora.scheduler.base.SchedulerException;
-import com.twitter.aurora.scheduler.base.Tasks;
-import com.twitter.aurora.scheduler.log.Log.Stream.InvalidPositionException;
-import com.twitter.aurora.scheduler.log.Log.Stream.StreamAccessException;
-import com.twitter.aurora.scheduler.storage.AttributeStore;
-import com.twitter.aurora.scheduler.storage.DistributedSnapshotStore;
-import com.twitter.aurora.scheduler.storage.ForwardingStore;
-import com.twitter.aurora.scheduler.storage.JobStore;
-import com.twitter.aurora.scheduler.storage.LockStore;
-import com.twitter.aurora.scheduler.storage.QuotaStore;
-import com.twitter.aurora.scheduler.storage.SchedulerStore;
-import com.twitter.aurora.scheduler.storage.SnapshotStore;
-import com.twitter.aurora.scheduler.storage.Storage;
-import com.twitter.aurora.scheduler.storage.Storage.NonVolatileStorage;
-import com.twitter.aurora.scheduler.storage.TaskStore;
-import com.twitter.aurora.scheduler.storage.entities.IJobConfiguration;
-import com.twitter.aurora.scheduler.storage.entities.IJobKey;
-import com.twitter.aurora.scheduler.storage.entities.ILock;
-import com.twitter.aurora.scheduler.storage.entities.ILockKey;
-import com.twitter.aurora.scheduler.storage.entities.IQuota;
-import com.twitter.aurora.scheduler.storage.entities.IScheduledTask;
-import com.twitter.aurora.scheduler.storage.entities.ITaskConfig;
-import com.twitter.aurora.scheduler.storage.log.LogManager.StreamManager;
-import com.twitter.aurora.scheduler.storage.log.LogManager.StreamManager.StreamTransaction;
 import com.twitter.common.application.ShutdownRegistry;
 import com.twitter.common.base.Closure;
 import com.twitter.common.inject.TimedInterceptor.Timed;
@@ -88,6 +46,49 @@ import com.twitter.common.quantity.Amount;
 import com.twitter.common.quantity.Time;
 import com.twitter.common.util.concurrent.ExecutorServiceShutdown;
 
+import org.apache.aurora.codec.ThriftBinaryCodec.CodingException;
+import org.apache.aurora.gen.HostAttributes;
+import org.apache.aurora.gen.MaintenanceMode;
+import org.apache.aurora.gen.storage.LogEntry;
+import org.apache.aurora.gen.storage.Op;
+import org.apache.aurora.gen.storage.RemoveJob;
+import org.apache.aurora.gen.storage.RemoveLock;
+import org.apache.aurora.gen.storage.RemoveQuota;
+import org.apache.aurora.gen.storage.RemoveTasks;
+import org.apache.aurora.gen.storage.RewriteTask;
+import org.apache.aurora.gen.storage.SaveAcceptedJob;
+import org.apache.aurora.gen.storage.SaveFrameworkId;
+import org.apache.aurora.gen.storage.SaveHostAttributes;
+import org.apache.aurora.gen.storage.SaveLock;
+import org.apache.aurora.gen.storage.SaveQuota;
+import org.apache.aurora.gen.storage.SaveTasks;
+import org.apache.aurora.gen.storage.Snapshot;
+import org.apache.aurora.scheduler.base.Query;
+import org.apache.aurora.scheduler.base.SchedulerException;
+import org.apache.aurora.scheduler.base.Tasks;
+import org.apache.aurora.scheduler.log.Log.Stream.InvalidPositionException;
+import org.apache.aurora.scheduler.log.Log.Stream.StreamAccessException;
+import org.apache.aurora.scheduler.storage.AttributeStore;
+import org.apache.aurora.scheduler.storage.DistributedSnapshotStore;
+import org.apache.aurora.scheduler.storage.ForwardingStore;
+import org.apache.aurora.scheduler.storage.JobStore;
+import org.apache.aurora.scheduler.storage.LockStore;
+import org.apache.aurora.scheduler.storage.QuotaStore;
+import org.apache.aurora.scheduler.storage.SchedulerStore;
+import org.apache.aurora.scheduler.storage.SnapshotStore;
+import org.apache.aurora.scheduler.storage.Storage;
+import org.apache.aurora.scheduler.storage.Storage.NonVolatileStorage;
+import org.apache.aurora.scheduler.storage.TaskStore;
+import org.apache.aurora.scheduler.storage.entities.IJobConfiguration;
+import org.apache.aurora.scheduler.storage.entities.IJobKey;
+import org.apache.aurora.scheduler.storage.entities.ILock;
+import org.apache.aurora.scheduler.storage.entities.ILockKey;
+import org.apache.aurora.scheduler.storage.entities.IQuota;
+import org.apache.aurora.scheduler.storage.entities.IScheduledTask;
+import org.apache.aurora.scheduler.storage.entities.ITaskConfig;
+import org.apache.aurora.scheduler.storage.log.LogManager.StreamManager;
+import org.apache.aurora.scheduler.storage.log.LogManager.StreamManager.StreamTransaction;
+
 import static com.google.common.base.Preconditions.checkNotNull;
 
 /**

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/java/org/apache/aurora/scheduler/storage/log/LogStorageModule.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/aurora/scheduler/storage/log/LogStorageModule.java b/src/main/java/org/apache/aurora/scheduler/storage/log/LogStorageModule.java
index 92568c8..7a0f25a 100644
--- a/src/main/java/org/apache/aurora/scheduler/storage/log/LogStorageModule.java
+++ b/src/main/java/org/apache/aurora/scheduler/storage/log/LogStorageModule.java
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.twitter.aurora.scheduler.storage.log;
+package org.apache.aurora.scheduler.storage.log;
 
 import java.lang.annotation.Annotation;
 
@@ -24,13 +24,6 @@ import com.google.inject.AbstractModule;
 import com.google.inject.Key;
 import com.google.inject.TypeLiteral;
 
-import com.twitter.aurora.scheduler.log.Log;
-import com.twitter.aurora.scheduler.storage.CallOrderEnforcingStorage;
-import com.twitter.aurora.scheduler.storage.DistributedSnapshotStore;
-import com.twitter.aurora.scheduler.storage.log.LogManager.MaxEntrySize;
-import com.twitter.aurora.scheduler.storage.log.LogManager.SnapshotSetting;
-import com.twitter.aurora.scheduler.storage.log.LogStorage.ShutdownGracePeriod;
-import com.twitter.aurora.scheduler.storage.log.LogStorage.SnapshotInterval;
 import com.twitter.common.application.ShutdownRegistry;
 import com.twitter.common.args.Arg;
 import com.twitter.common.args.CmdLine;
@@ -39,6 +32,14 @@ import com.twitter.common.quantity.Data;
 import com.twitter.common.quantity.Time;
 import com.twitter.common.util.Clock;
 
+import org.apache.aurora.scheduler.log.Log;
+import org.apache.aurora.scheduler.storage.CallOrderEnforcingStorage;
+import org.apache.aurora.scheduler.storage.DistributedSnapshotStore;
+import org.apache.aurora.scheduler.storage.log.LogManager.MaxEntrySize;
+import org.apache.aurora.scheduler.storage.log.LogManager.SnapshotSetting;
+import org.apache.aurora.scheduler.storage.log.LogStorage.ShutdownGracePeriod;
+import org.apache.aurora.scheduler.storage.log.LogStorage.SnapshotInterval;
+
 /**
  * Bindings for scheduler distributed log based storage.
  * <p/>

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/java/org/apache/aurora/scheduler/storage/log/SnapshotStoreImpl.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/aurora/scheduler/storage/log/SnapshotStoreImpl.java b/src/main/java/org/apache/aurora/scheduler/storage/log/SnapshotStoreImpl.java
index df6b899..5571fd2 100644
--- a/src/main/java/org/apache/aurora/scheduler/storage/log/SnapshotStoreImpl.java
+++ b/src/main/java/org/apache/aurora/scheduler/storage/log/SnapshotStoreImpl.java
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.twitter.aurora.scheduler.storage.log;
+package org.apache.aurora.scheduler.storage.log;
 
 import java.util.Arrays;
 import java.util.Map;
@@ -24,31 +24,32 @@ import javax.inject.Inject;
 
 import com.google.common.collect.ImmutableSet;
 
-import com.twitter.aurora.gen.HostAttributes;
-import com.twitter.aurora.gen.Lock;
-import com.twitter.aurora.gen.storage.QuotaConfiguration;
-import com.twitter.aurora.gen.storage.SchedulerMetadata;
-import com.twitter.aurora.gen.storage.Snapshot;
-import com.twitter.aurora.gen.storage.StoredJob;
-import com.twitter.aurora.scheduler.base.Query;
-import com.twitter.aurora.scheduler.storage.SnapshotStore;
-import com.twitter.aurora.scheduler.storage.Storage;
-import com.twitter.aurora.scheduler.storage.Storage.MutableStoreProvider;
-import com.twitter.aurora.scheduler.storage.Storage.MutateWork;
-import com.twitter.aurora.scheduler.storage.Storage.StoreProvider;
-import com.twitter.aurora.scheduler.storage.Storage.Volatile;
-import com.twitter.aurora.scheduler.storage.Storage.Work;
-import com.twitter.aurora.scheduler.storage.entities.IJobConfiguration;
-import com.twitter.aurora.scheduler.storage.entities.ILock;
-import com.twitter.aurora.scheduler.storage.entities.IQuota;
-import com.twitter.aurora.scheduler.storage.entities.IScheduledTask;
 import com.twitter.common.inject.TimedInterceptor.Timed;
 import com.twitter.common.util.BuildInfo;
 import com.twitter.common.util.Clock;
 
+import org.apache.aurora.gen.HostAttributes;
+import org.apache.aurora.gen.Lock;
+import org.apache.aurora.gen.storage.QuotaConfiguration;
+import org.apache.aurora.gen.storage.SchedulerMetadata;
+import org.apache.aurora.gen.storage.Snapshot;
+import org.apache.aurora.gen.storage.StoredJob;
+import org.apache.aurora.scheduler.base.Query;
+import org.apache.aurora.scheduler.storage.SnapshotStore;
+import org.apache.aurora.scheduler.storage.Storage;
+import org.apache.aurora.scheduler.storage.Storage.MutableStoreProvider;
+import org.apache.aurora.scheduler.storage.Storage.MutateWork;
+import org.apache.aurora.scheduler.storage.Storage.StoreProvider;
+import org.apache.aurora.scheduler.storage.Storage.Volatile;
+import org.apache.aurora.scheduler.storage.Storage.Work;
+import org.apache.aurora.scheduler.storage.entities.IJobConfiguration;
+import org.apache.aurora.scheduler.storage.entities.ILock;
+import org.apache.aurora.scheduler.storage.entities.IQuota;
+import org.apache.aurora.scheduler.storage.entities.IScheduledTask;
+
 import static com.google.common.base.Preconditions.checkNotNull;
 
-import static com.twitter.aurora.gen.apiConstants.CURRENT_API_VERSION;
+import static org.apache.aurora.gen.apiConstants.CURRENT_API_VERSION;
 
 /**
  * Snapshot store implementation that delegates to underlying snapshot stores by

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/java/org/apache/aurora/scheduler/storage/log/testing/LogOpMatcher.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/aurora/scheduler/storage/log/testing/LogOpMatcher.java b/src/main/java/org/apache/aurora/scheduler/storage/log/testing/LogOpMatcher.java
index a4c0126..ae1f72f 100644
--- a/src/main/java/org/apache/aurora/scheduler/storage/log/testing/LogOpMatcher.java
+++ b/src/main/java/org/apache/aurora/scheduler/storage/log/testing/LogOpMatcher.java
@@ -13,25 +13,25 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.twitter.aurora.scheduler.storage.log.testing;
+package org.apache.aurora.scheduler.storage.log.testing;
 
 import com.google.common.base.Preconditions;
 import com.google.common.collect.ImmutableList;
 
+import org.apache.aurora.codec.ThriftBinaryCodec;
+import org.apache.aurora.codec.ThriftBinaryCodec.CodingException;
+import org.apache.aurora.gen.storage.LogEntry;
+import org.apache.aurora.gen.storage.Op;
+import org.apache.aurora.gen.storage.Snapshot;
+import org.apache.aurora.gen.storage.Transaction;
+import org.apache.aurora.gen.storage.storageConstants;
+import org.apache.aurora.scheduler.log.Log.Position;
+import org.apache.aurora.scheduler.log.Log.Stream;
+
 import org.easymock.EasyMock;
 import org.easymock.IArgumentMatcher;
 import org.easymock.IExpectationSetters;
 
-import com.twitter.aurora.codec.ThriftBinaryCodec;
-import com.twitter.aurora.codec.ThriftBinaryCodec.CodingException;
-import com.twitter.aurora.gen.storage.LogEntry;
-import com.twitter.aurora.gen.storage.Op;
-import com.twitter.aurora.gen.storage.Snapshot;
-import com.twitter.aurora.gen.storage.Transaction;
-import com.twitter.aurora.gen.storage.storageConstants;
-import com.twitter.aurora.scheduler.log.Log.Position;
-import com.twitter.aurora.scheduler.log.Log.Stream;
-
 import static org.easymock.EasyMock.expect;
 
 /**

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/java/org/apache/aurora/scheduler/storage/mem/Interner.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/aurora/scheduler/storage/mem/Interner.java b/src/main/java/org/apache/aurora/scheduler/storage/mem/Interner.java
index bf05caa..f157d81 100644
--- a/src/main/java/org/apache/aurora/scheduler/storage/mem/Interner.java
+++ b/src/main/java/org/apache/aurora/scheduler/storage/mem/Interner.java
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.twitter.aurora.scheduler.storage.mem;
+package org.apache.aurora.scheduler.storage.mem;
 
 import java.util.Map;
 import java.util.Set;

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/java/org/apache/aurora/scheduler/storage/mem/MemAttributeStore.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/aurora/scheduler/storage/mem/MemAttributeStore.java b/src/main/java/org/apache/aurora/scheduler/storage/mem/MemAttributeStore.java
index 6c383c7..c7ff5d9 100644
--- a/src/main/java/org/apache/aurora/scheduler/storage/mem/MemAttributeStore.java
+++ b/src/main/java/org/apache/aurora/scheduler/storage/mem/MemAttributeStore.java
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.twitter.aurora.scheduler.storage.mem;
+package org.apache.aurora.scheduler.storage.mem;
 
 import java.util.Set;
 import java.util.concurrent.ConcurrentMap;
@@ -22,10 +22,10 @@ import com.google.common.base.Optional;
 import com.google.common.collect.ImmutableSet;
 import com.google.common.collect.Maps;
 
-import com.twitter.aurora.gen.Attribute;
-import com.twitter.aurora.gen.HostAttributes;
-import com.twitter.aurora.gen.MaintenanceMode;
-import com.twitter.aurora.scheduler.storage.AttributeStore.Mutable;
+import org.apache.aurora.gen.Attribute;
+import org.apache.aurora.gen.HostAttributes;
+import org.apache.aurora.gen.MaintenanceMode;
+import org.apache.aurora.scheduler.storage.AttributeStore.Mutable;
 
 /**
  * An in-memory attribute store.

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/java/org/apache/aurora/scheduler/storage/mem/MemJobStore.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/aurora/scheduler/storage/mem/MemJobStore.java b/src/main/java/org/apache/aurora/scheduler/storage/mem/MemJobStore.java
index 8268e8d..471b7a5 100644
--- a/src/main/java/org/apache/aurora/scheduler/storage/mem/MemJobStore.java
+++ b/src/main/java/org/apache/aurora/scheduler/storage/mem/MemJobStore.java
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.twitter.aurora.scheduler.storage.mem;
+package org.apache.aurora.scheduler.storage.mem;
 
 import java.util.Map;
 import java.util.Set;
@@ -27,10 +27,10 @@ import com.google.common.cache.LoadingCache;
 import com.google.common.collect.ImmutableSet;
 import com.google.common.collect.Maps;
 
-import com.twitter.aurora.scheduler.base.JobKeys;
-import com.twitter.aurora.scheduler.storage.JobStore;
-import com.twitter.aurora.scheduler.storage.entities.IJobConfiguration;
-import com.twitter.aurora.scheduler.storage.entities.IJobKey;
+import org.apache.aurora.scheduler.base.JobKeys;
+import org.apache.aurora.scheduler.storage.JobStore;
+import org.apache.aurora.scheduler.storage.entities.IJobConfiguration;
+import org.apache.aurora.scheduler.storage.entities.IJobKey;
 
 import static com.google.common.base.Preconditions.checkNotNull;
 

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/java/org/apache/aurora/scheduler/storage/mem/MemLockStore.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/aurora/scheduler/storage/mem/MemLockStore.java b/src/main/java/org/apache/aurora/scheduler/storage/mem/MemLockStore.java
index 1ced973..df04d6d 100644
--- a/src/main/java/org/apache/aurora/scheduler/storage/mem/MemLockStore.java
+++ b/src/main/java/org/apache/aurora/scheduler/storage/mem/MemLockStore.java
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.twitter.aurora.scheduler.storage.mem;
+package org.apache.aurora.scheduler.storage.mem;
 
 import java.util.Map;
 import java.util.Set;
@@ -22,9 +22,9 @@ import com.google.common.base.Optional;
 import com.google.common.collect.ImmutableSet;
 import com.google.common.collect.Maps;
 
-import com.twitter.aurora.scheduler.storage.LockStore;
-import com.twitter.aurora.scheduler.storage.entities.ILock;
-import com.twitter.aurora.scheduler.storage.entities.ILockKey;
+import org.apache.aurora.scheduler.storage.LockStore;
+import org.apache.aurora.scheduler.storage.entities.ILock;
+import org.apache.aurora.scheduler.storage.entities.ILockKey;
 
 /**
  * An in-memory lock store.

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/java/org/apache/aurora/scheduler/storage/mem/MemQuotaStore.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/aurora/scheduler/storage/mem/MemQuotaStore.java b/src/main/java/org/apache/aurora/scheduler/storage/mem/MemQuotaStore.java
index 855b39c..54ed29d 100644
--- a/src/main/java/org/apache/aurora/scheduler/storage/mem/MemQuotaStore.java
+++ b/src/main/java/org/apache/aurora/scheduler/storage/mem/MemQuotaStore.java
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.twitter.aurora.scheduler.storage.mem;
+package org.apache.aurora.scheduler.storage.mem;
 
 import java.util.Map;
 
@@ -21,8 +21,8 @@ import com.google.common.base.Optional;
 import com.google.common.collect.ImmutableMap;
 import com.google.common.collect.Maps;
 
-import com.twitter.aurora.scheduler.storage.QuotaStore;
-import com.twitter.aurora.scheduler.storage.entities.IQuota;
+import org.apache.aurora.scheduler.storage.QuotaStore;
+import org.apache.aurora.scheduler.storage.entities.IQuota;
 
 import static com.google.common.base.Preconditions.checkNotNull;
 

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/java/org/apache/aurora/scheduler/storage/mem/MemSchedulerStore.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/aurora/scheduler/storage/mem/MemSchedulerStore.java b/src/main/java/org/apache/aurora/scheduler/storage/mem/MemSchedulerStore.java
index 19bf4ec..b4dd5aa 100644
--- a/src/main/java/org/apache/aurora/scheduler/storage/mem/MemSchedulerStore.java
+++ b/src/main/java/org/apache/aurora/scheduler/storage/mem/MemSchedulerStore.java
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.twitter.aurora.scheduler.storage.mem;
+package org.apache.aurora.scheduler.storage.mem;
 
 import java.util.concurrent.atomic.AtomicReference;
 
@@ -21,7 +21,7 @@ import javax.annotation.Nullable;
 
 import com.google.common.util.concurrent.Atomics;
 
-import com.twitter.aurora.scheduler.storage.SchedulerStore;
+import org.apache.aurora.scheduler.storage.SchedulerStore;
 
 /**
  * An in-memory scheduler store.

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/java/org/apache/aurora/scheduler/storage/mem/MemStorage.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/aurora/scheduler/storage/mem/MemStorage.java b/src/main/java/org/apache/aurora/scheduler/storage/mem/MemStorage.java
index 438c023..1cdf15e 100644
--- a/src/main/java/org/apache/aurora/scheduler/storage/mem/MemStorage.java
+++ b/src/main/java/org/apache/aurora/scheduler/storage/mem/MemStorage.java
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.twitter.aurora.scheduler.storage.mem;
+package org.apache.aurora.scheduler.storage.mem;
 
 import java.util.concurrent.atomic.AtomicLong;
 
@@ -21,17 +21,18 @@ import javax.inject.Inject;
 
 import com.google.common.annotations.VisibleForTesting;
 
-import com.twitter.aurora.scheduler.storage.AttributeStore;
-import com.twitter.aurora.scheduler.storage.JobStore;
-import com.twitter.aurora.scheduler.storage.LockStore;
-import com.twitter.aurora.scheduler.storage.QuotaStore;
-import com.twitter.aurora.scheduler.storage.ReadWriteLockManager;
-import com.twitter.aurora.scheduler.storage.SchedulerStore;
-import com.twitter.aurora.scheduler.storage.Storage;
-import com.twitter.aurora.scheduler.storage.TaskStore;
 import com.twitter.common.inject.TimedInterceptor.Timed;
 import com.twitter.common.stats.Stats;
 
+import org.apache.aurora.scheduler.storage.AttributeStore;
+import org.apache.aurora.scheduler.storage.JobStore;
+import org.apache.aurora.scheduler.storage.LockStore;
+import org.apache.aurora.scheduler.storage.QuotaStore;
+import org.apache.aurora.scheduler.storage.ReadWriteLockManager;
+import org.apache.aurora.scheduler.storage.SchedulerStore;
+import org.apache.aurora.scheduler.storage.Storage;
+import org.apache.aurora.scheduler.storage.TaskStore;
+
 import static com.google.common.base.Preconditions.checkNotNull;
 
 /**

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/java/org/apache/aurora/scheduler/storage/mem/MemStorageModule.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/aurora/scheduler/storage/mem/MemTaskStore.java b/src/main/java/org/apache/aurora/scheduler/storage/mem/MemTaskStore.java
index d02511f..7abd7e1 100644
--- a/src/main/java/org/apache/aurora/scheduler/storage/mem/MemTaskStore.java
+++ b/src/main/java/org/apache/aurora/scheduler/storage/mem/MemTaskStore.java
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.twitter.aurora.scheduler.storage.mem;
+package org.apache.aurora.scheduler.storage.mem;
 
 import java.util.Collection;
 import java.util.Map;
@@ -36,18 +36,6 @@ import com.google.common.collect.Maps;
 import com.google.common.collect.Multimap;
 import com.google.common.collect.Multimaps;
 
-import org.apache.commons.lang.StringUtils;
-
-import com.twitter.aurora.gen.ScheduledTask;
-import com.twitter.aurora.gen.TaskConfig;
-import com.twitter.aurora.gen.TaskQuery;
-import com.twitter.aurora.scheduler.base.JobKeys;
-import com.twitter.aurora.scheduler.base.Query;
-import com.twitter.aurora.scheduler.base.Tasks;
-import com.twitter.aurora.scheduler.storage.TaskStore;
-import com.twitter.aurora.scheduler.storage.entities.IJobKey;
-import com.twitter.aurora.scheduler.storage.entities.IScheduledTask;
-import com.twitter.aurora.scheduler.storage.entities.ITaskConfig;
 import com.twitter.common.args.Arg;
 import com.twitter.common.args.CmdLine;
 import com.twitter.common.base.MorePreconditions;
@@ -56,6 +44,19 @@ import com.twitter.common.quantity.Amount;
 import com.twitter.common.quantity.Time;
 import com.twitter.common.stats.Stats;
 
+import org.apache.aurora.gen.ScheduledTask;
+import org.apache.aurora.gen.TaskConfig;
+import org.apache.aurora.gen.TaskQuery;
+import org.apache.aurora.scheduler.base.JobKeys;
+import org.apache.aurora.scheduler.base.Query;
+import org.apache.aurora.scheduler.base.Tasks;
+import org.apache.aurora.scheduler.storage.TaskStore;
+import org.apache.aurora.scheduler.storage.entities.IJobKey;
+import org.apache.aurora.scheduler.storage.entities.IScheduledTask;
+import org.apache.aurora.scheduler.storage.entities.ITaskConfig;
+
+import org.apache.commons.lang.StringUtils;
+
 import static com.google.common.base.Preconditions.checkNotNull;
 
 /**

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/java/org/apache/aurora/scheduler/storage/mem/Util.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/aurora/scheduler/storage/mem/Util.java b/src/main/java/org/apache/aurora/scheduler/storage/mem/Util.java
index cf1b057..0368d46 100644
--- a/src/main/java/org/apache/aurora/scheduler/storage/mem/Util.java
+++ b/src/main/java/org/apache/aurora/scheduler/storage/mem/Util.java
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.twitter.aurora.scheduler.storage.mem;
+package org.apache.aurora.scheduler.storage.mem;
 
 import javax.annotation.Nullable;
 

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/java/org/apache/aurora/scheduler/storage/testing/StorageTestUtil.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/aurora/scheduler/storage/testing/StorageTestUtil.java b/src/main/java/org/apache/aurora/scheduler/storage/testing/StorageTestUtil.java
index d735828..5832b3f 100644
--- a/src/main/java/org/apache/aurora/scheduler/storage/testing/StorageTestUtil.java
+++ b/src/main/java/org/apache/aurora/scheduler/storage/testing/StorageTestUtil.java
@@ -13,29 +13,30 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.twitter.aurora.scheduler.storage.testing;
+package org.apache.aurora.scheduler.storage.testing;
 
 import com.google.common.collect.ImmutableSet;
 
+import com.twitter.common.testing.easymock.EasyMockTest;
+
+import org.apache.aurora.scheduler.base.Query;
+import org.apache.aurora.scheduler.storage.AttributeStore;
+import org.apache.aurora.scheduler.storage.JobStore;
+import org.apache.aurora.scheduler.storage.LockStore;
+import org.apache.aurora.scheduler.storage.QuotaStore;
+import org.apache.aurora.scheduler.storage.SchedulerStore;
+import org.apache.aurora.scheduler.storage.Storage.MutableStoreProvider;
+import org.apache.aurora.scheduler.storage.Storage.MutateWork;
+import org.apache.aurora.scheduler.storage.Storage.NonVolatileStorage;
+import org.apache.aurora.scheduler.storage.Storage.StoreProvider;
+import org.apache.aurora.scheduler.storage.Storage.Work;
+import org.apache.aurora.scheduler.storage.TaskStore;
+import org.apache.aurora.scheduler.storage.entities.IScheduledTask;
+
 import org.easymock.Capture;
 import org.easymock.IAnswer;
 import org.easymock.IExpectationSetters;
 
-import com.twitter.aurora.scheduler.base.Query;
-import com.twitter.aurora.scheduler.storage.AttributeStore;
-import com.twitter.aurora.scheduler.storage.JobStore;
-import com.twitter.aurora.scheduler.storage.LockStore;
-import com.twitter.aurora.scheduler.storage.QuotaStore;
-import com.twitter.aurora.scheduler.storage.SchedulerStore;
-import com.twitter.aurora.scheduler.storage.Storage.MutableStoreProvider;
-import com.twitter.aurora.scheduler.storage.Storage.MutateWork;
-import com.twitter.aurora.scheduler.storage.Storage.NonVolatileStorage;
-import com.twitter.aurora.scheduler.storage.Storage.StoreProvider;
-import com.twitter.aurora.scheduler.storage.Storage.Work;
-import com.twitter.aurora.scheduler.storage.TaskStore;
-import com.twitter.aurora.scheduler.storage.entities.IScheduledTask;
-import com.twitter.common.testing.easymock.EasyMockTest;
-
 import static org.easymock.EasyMock.capture;
 import static org.easymock.EasyMock.expect;
 

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/java/org/apache/aurora/scheduler/thrift/SchedulerAPIServlet.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/aurora/scheduler/thrift/SchedulerAPIServlet.java b/src/main/java/org/apache/aurora/scheduler/thrift/SchedulerAPIServlet.java
index 2acf5c8..689b479 100644
--- a/src/main/java/org/apache/aurora/scheduler/thrift/SchedulerAPIServlet.java
+++ b/src/main/java/org/apache/aurora/scheduler/thrift/SchedulerAPIServlet.java
@@ -1,12 +1,12 @@
-package com.twitter.aurora.scheduler.thrift;
+package org.apache.aurora.scheduler.thrift;
 
 import javax.inject.Inject;
 
+import org.apache.aurora.gen.AuroraAdmin;
+
 import org.apache.thrift.protocol.TJSONProtocol;
 import org.apache.thrift.server.TServlet;
 
-import com.twitter.aurora.gen.AuroraAdmin;
-
 /**
  * A servlet that exposes the scheduler Thrift API over HTTP/JSON.
  */

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/java/org/apache/aurora/scheduler/thrift/SchedulerThriftInterface.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/aurora/scheduler/thrift/SchedulerThriftInterface.java b/src/main/java/org/apache/aurora/scheduler/thrift/SchedulerThriftInterface.java
index 3ff0f1c..177cb84 100644
--- a/src/main/java/org/apache/aurora/scheduler/thrift/SchedulerThriftInterface.java
+++ b/src/main/java/org/apache/aurora/scheduler/thrift/SchedulerThriftInterface.java
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.twitter.aurora.scheduler.thrift;
+package org.apache.aurora.scheduler.thrift;
 
 import java.util.Collection;
 import java.util.List;
@@ -43,79 +43,6 @@ import com.google.common.collect.Multimap;
 import com.google.common.collect.Multimaps;
 import com.google.common.collect.Sets;
 
-import org.apache.commons.lang.StringUtils;
-
-import com.twitter.aurora.auth.CapabilityValidator;
-import com.twitter.aurora.auth.CapabilityValidator.AuditCheck;
-import com.twitter.aurora.auth.CapabilityValidator.Capability;
-import com.twitter.aurora.auth.SessionValidator.AuthFailedException;
-import com.twitter.aurora.gen.AcquireLockResult;
-import com.twitter.aurora.gen.AddInstancesConfig;
-import com.twitter.aurora.gen.AuroraAdmin;
-import com.twitter.aurora.gen.ConfigRewrite;
-import com.twitter.aurora.gen.DrainHostsResult;
-import com.twitter.aurora.gen.EndMaintenanceResult;
-import com.twitter.aurora.gen.GetJobsResult;
-import com.twitter.aurora.gen.GetQuotaResult;
-import com.twitter.aurora.gen.Hosts;
-import com.twitter.aurora.gen.InstanceConfigRewrite;
-import com.twitter.aurora.gen.InstanceKey;
-import com.twitter.aurora.gen.JobConfigRewrite;
-import com.twitter.aurora.gen.JobConfigValidation;
-import com.twitter.aurora.gen.JobConfiguration;
-import com.twitter.aurora.gen.JobKey;
-import com.twitter.aurora.gen.JobSummary;
-import com.twitter.aurora.gen.JobSummaryResult;
-import com.twitter.aurora.gen.ListBackupsResult;
-import com.twitter.aurora.gen.Lock;
-import com.twitter.aurora.gen.LockKey;
-import com.twitter.aurora.gen.LockValidation;
-import com.twitter.aurora.gen.MaintenanceStatusResult;
-import com.twitter.aurora.gen.PopulateJobResult;
-import com.twitter.aurora.gen.QueryRecoveryResult;
-import com.twitter.aurora.gen.Quota;
-import com.twitter.aurora.gen.Response;
-import com.twitter.aurora.gen.ResponseCode;
-import com.twitter.aurora.gen.Result;
-import com.twitter.aurora.gen.RewriteConfigsRequest;
-import com.twitter.aurora.gen.ScheduleStatus;
-import com.twitter.aurora.gen.ScheduleStatusResult;
-import com.twitter.aurora.gen.SessionKey;
-import com.twitter.aurora.gen.StartMaintenanceResult;
-import com.twitter.aurora.gen.TaskConfig;
-import com.twitter.aurora.gen.TaskQuery;
-import com.twitter.aurora.scheduler.base.JobKeys;
-import com.twitter.aurora.scheduler.base.Query;
-import com.twitter.aurora.scheduler.base.ScheduleException;
-import com.twitter.aurora.scheduler.base.Tasks;
-import com.twitter.aurora.scheduler.configuration.ConfigurationManager;
-import com.twitter.aurora.scheduler.configuration.ConfigurationManager.TaskDescriptionException;
-import com.twitter.aurora.scheduler.configuration.SanitizedConfiguration;
-import com.twitter.aurora.scheduler.quota.Quotas;
-import com.twitter.aurora.scheduler.state.CronJobManager;
-import com.twitter.aurora.scheduler.state.LockManager;
-import com.twitter.aurora.scheduler.state.LockManager.LockException;
-import com.twitter.aurora.scheduler.state.MaintenanceController;
-import com.twitter.aurora.scheduler.state.SchedulerCore;
-import com.twitter.aurora.scheduler.storage.JobStore;
-import com.twitter.aurora.scheduler.storage.Storage;
-import com.twitter.aurora.scheduler.storage.Storage.MutableStoreProvider;
-import com.twitter.aurora.scheduler.storage.Storage.MutateWork;
-import com.twitter.aurora.scheduler.storage.Storage.StoreProvider;
-import com.twitter.aurora.scheduler.storage.Storage.Work;
-import com.twitter.aurora.scheduler.storage.backup.Recovery;
-import com.twitter.aurora.scheduler.storage.backup.Recovery.RecoveryException;
-import com.twitter.aurora.scheduler.storage.backup.StorageBackup;
-import com.twitter.aurora.scheduler.storage.entities.IAssignedTask;
-import com.twitter.aurora.scheduler.storage.entities.IJobConfiguration;
-import com.twitter.aurora.scheduler.storage.entities.IJobKey;
-import com.twitter.aurora.scheduler.storage.entities.ILock;
-import com.twitter.aurora.scheduler.storage.entities.ILockKey;
-import com.twitter.aurora.scheduler.storage.entities.IQuota;
-import com.twitter.aurora.scheduler.storage.entities.IScheduledTask;
-import com.twitter.aurora.scheduler.storage.entities.ITaskConfig;
-import com.twitter.aurora.scheduler.thrift.auth.DecoratedThrift;
-import com.twitter.aurora.scheduler.thrift.auth.Requires;
 import com.twitter.common.args.Arg;
 import com.twitter.common.args.CmdLine;
 import com.twitter.common.base.MorePreconditions;
@@ -124,17 +51,92 @@ import com.twitter.common.quantity.Amount;
 import com.twitter.common.quantity.Time;
 import com.twitter.common.util.BackoffHelper;
 
+import org.apache.aurora.auth.CapabilityValidator;
+import org.apache.aurora.auth.CapabilityValidator.AuditCheck;
+import org.apache.aurora.auth.CapabilityValidator.Capability;
+import org.apache.aurora.auth.SessionValidator.AuthFailedException;
+import org.apache.aurora.gen.AcquireLockResult;
+import org.apache.aurora.gen.AddInstancesConfig;
+import org.apache.aurora.gen.AuroraAdmin;
+import org.apache.aurora.gen.ConfigRewrite;
+import org.apache.aurora.gen.DrainHostsResult;
+import org.apache.aurora.gen.EndMaintenanceResult;
+import org.apache.aurora.gen.GetJobsResult;
+import org.apache.aurora.gen.GetQuotaResult;
+import org.apache.aurora.gen.Hosts;
+import org.apache.aurora.gen.InstanceConfigRewrite;
+import org.apache.aurora.gen.InstanceKey;
+import org.apache.aurora.gen.JobConfigRewrite;
+import org.apache.aurora.gen.JobConfigValidation;
+import org.apache.aurora.gen.JobConfiguration;
+import org.apache.aurora.gen.JobKey;
+import org.apache.aurora.gen.JobSummary;
+import org.apache.aurora.gen.JobSummaryResult;
+import org.apache.aurora.gen.ListBackupsResult;
+import org.apache.aurora.gen.Lock;
+import org.apache.aurora.gen.LockKey;
+import org.apache.aurora.gen.LockValidation;
+import org.apache.aurora.gen.MaintenanceStatusResult;
+import org.apache.aurora.gen.PopulateJobResult;
+import org.apache.aurora.gen.QueryRecoveryResult;
+import org.apache.aurora.gen.Quota;
+import org.apache.aurora.gen.Response;
+import org.apache.aurora.gen.ResponseCode;
+import org.apache.aurora.gen.Result;
+import org.apache.aurora.gen.RewriteConfigsRequest;
+import org.apache.aurora.gen.ScheduleStatus;
+import org.apache.aurora.gen.ScheduleStatusResult;
+import org.apache.aurora.gen.SessionKey;
+import org.apache.aurora.gen.StartMaintenanceResult;
+import org.apache.aurora.gen.TaskConfig;
+import org.apache.aurora.gen.TaskQuery;
+import org.apache.aurora.scheduler.base.JobKeys;
+import org.apache.aurora.scheduler.base.Query;
+import org.apache.aurora.scheduler.base.ScheduleException;
+import org.apache.aurora.scheduler.base.Tasks;
+import org.apache.aurora.scheduler.configuration.ConfigurationManager;
+import org.apache.aurora.scheduler.configuration.ConfigurationManager.TaskDescriptionException;
+import org.apache.aurora.scheduler.configuration.SanitizedConfiguration;
+import org.apache.aurora.scheduler.quota.Quotas;
+import org.apache.aurora.scheduler.state.CronJobManager;
+import org.apache.aurora.scheduler.state.LockManager;
+import org.apache.aurora.scheduler.state.LockManager.LockException;
+import org.apache.aurora.scheduler.state.MaintenanceController;
+import org.apache.aurora.scheduler.state.SchedulerCore;
+import org.apache.aurora.scheduler.storage.JobStore;
+import org.apache.aurora.scheduler.storage.Storage;
+import org.apache.aurora.scheduler.storage.Storage.MutableStoreProvider;
+import org.apache.aurora.scheduler.storage.Storage.MutateWork;
+import org.apache.aurora.scheduler.storage.Storage.StoreProvider;
+import org.apache.aurora.scheduler.storage.Storage.Work;
+import org.apache.aurora.scheduler.storage.backup.Recovery;
+import org.apache.aurora.scheduler.storage.backup.Recovery.RecoveryException;
+import org.apache.aurora.scheduler.storage.backup.StorageBackup;
+import org.apache.aurora.scheduler.storage.entities.IAssignedTask;
+import org.apache.aurora.scheduler.storage.entities.IJobConfiguration;
+import org.apache.aurora.scheduler.storage.entities.IJobKey;
+import org.apache.aurora.scheduler.storage.entities.ILock;
+import org.apache.aurora.scheduler.storage.entities.ILockKey;
+import org.apache.aurora.scheduler.storage.entities.IQuota;
+import org.apache.aurora.scheduler.storage.entities.IScheduledTask;
+import org.apache.aurora.scheduler.storage.entities.ITaskConfig;
+import org.apache.aurora.scheduler.thrift.auth.DecoratedThrift;
+import org.apache.aurora.scheduler.thrift.auth.Requires;
+
+import org.apache.commons.lang.StringUtils;
+
 import static com.google.common.base.Preconditions.checkNotNull;
 
-import static com.twitter.aurora.auth.SessionValidator.SessionContext;
-import static com.twitter.aurora.gen.ResponseCode.AUTH_FAILED;
-import static com.twitter.aurora.gen.ResponseCode.ERROR;
-import static com.twitter.aurora.gen.ResponseCode.INVALID_REQUEST;
-import static com.twitter.aurora.gen.ResponseCode.LOCK_ERROR;
-import static com.twitter.aurora.gen.ResponseCode.OK;
-import static com.twitter.aurora.gen.apiConstants.CURRENT_API_VERSION;
 import static com.twitter.common.base.MorePreconditions.checkNotBlank;
 
+import static org.apache.aurora.auth.SessionValidator.SessionContext;
+import static org.apache.aurora.gen.ResponseCode.AUTH_FAILED;
+import static org.apache.aurora.gen.ResponseCode.ERROR;
+import static org.apache.aurora.gen.ResponseCode.INVALID_REQUEST;
+import static org.apache.aurora.gen.ResponseCode.LOCK_ERROR;
+import static org.apache.aurora.gen.ResponseCode.OK;
+import static org.apache.aurora.gen.apiConstants.CURRENT_API_VERSION;
+
 /**
  * Aurora scheduler thrift server implementation.
  * <p>

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/java/org/apache/aurora/scheduler/thrift/ThriftConfiguration.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/aurora/scheduler/thrift/ThriftConfiguration.java b/src/main/java/org/apache/aurora/scheduler/thrift/ThriftConfiguration.java
index c6e9b18..4659a0d 100644
--- a/src/main/java/org/apache/aurora/scheduler/thrift/ThriftConfiguration.java
+++ b/src/main/java/org/apache/aurora/scheduler/thrift/ThriftConfiguration.java
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.twitter.aurora.scheduler.thrift;
+package org.apache.aurora.scheduler.thrift;
 
 import java.io.IOException;
 import java.io.InputStream;

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/java/org/apache/aurora/scheduler/thrift/ThriftModule.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/aurora/scheduler/thrift/ThriftModule.java b/src/main/java/org/apache/aurora/scheduler/thrift/ThriftModule.java
index cca9053..2514cfe 100644
--- a/src/main/java/org/apache/aurora/scheduler/thrift/ThriftModule.java
+++ b/src/main/java/org/apache/aurora/scheduler/thrift/ThriftModule.java
@@ -13,17 +13,18 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.twitter.aurora.scheduler.thrift;
+package org.apache.aurora.scheduler.thrift;
 
 import javax.inject.Singleton;
 
 import com.google.inject.AbstractModule;
 
-import com.twitter.aurora.gen.AuroraAdmin;
-import com.twitter.aurora.scheduler.thrift.aop.AopModule;
 import com.twitter.common.application.http.Registration;
 import com.twitter.common.application.modules.LifecycleModule;
 
+import org.apache.aurora.gen.AuroraAdmin;
+import org.apache.aurora.scheduler.thrift.aop.AopModule;
+
 /**
  * Binding module to configure a thrift server.
  */

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/java/org/apache/aurora/scheduler/thrift/ThriftServer.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/aurora/scheduler/thrift/ThriftServer.java b/src/main/java/org/apache/aurora/scheduler/thrift/ThriftServer.java
index 7b9abd1..3581412 100644
--- a/src/main/java/org/apache/aurora/scheduler/thrift/ThriftServer.java
+++ b/src/main/java/org/apache/aurora/scheduler/thrift/ThriftServer.java
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.twitter.aurora.scheduler.thrift;
+package org.apache.aurora.scheduler.thrift;
 
 import java.net.ServerSocket;
 import java.util.logging.Level;
@@ -22,14 +22,14 @@ import java.util.logging.Logger;
 import com.google.common.base.Preconditions;
 import com.google.common.util.concurrent.ThreadFactoryBuilder;
 
+import com.twitter.thrift.Status;
+
 import org.apache.thrift.TProcessor;
 import org.apache.thrift.protocol.TBinaryProtocol;
 import org.apache.thrift.server.TServer;
 import org.apache.thrift.server.TThreadPoolServer;
 import org.apache.thrift.transport.TServerSocket;
 
-import com.twitter.thrift.Status;
-
 class ThriftServer {
   private static final Logger LOG = Logger.getLogger(ThriftServer.class.getName());
 

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/java/org/apache/aurora/scheduler/thrift/ThriftServerLauncher.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/aurora/scheduler/thrift/ThriftServerLauncher.java b/src/main/java/org/apache/aurora/scheduler/thrift/ThriftServerLauncher.java
index 6743060..13b4dd1 100644
--- a/src/main/java/org/apache/aurora/scheduler/thrift/ThriftServerLauncher.java
+++ b/src/main/java/org/apache/aurora/scheduler/thrift/ThriftServerLauncher.java
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.twitter.aurora.scheduler.thrift;
+package org.apache.aurora.scheduler.thrift;
 
 import java.io.IOException;
 import java.io.InputStream;
@@ -30,12 +30,13 @@ import javax.net.ssl.SSLServerSocketFactory;
 
 import com.google.common.base.Optional;
 
-import com.twitter.aurora.gen.AuroraAdmin;
-import com.twitter.aurora.gen.AuroraAdmin.Iface;
 import com.twitter.common.application.modules.LifecycleModule.ServiceRunner;
 import com.twitter.common.application.modules.LocalServiceRegistry.LocalService;
 import com.twitter.common.base.Command;
 
+import org.apache.aurora.gen.AuroraAdmin;
+import org.apache.aurora.gen.AuroraAdmin.Iface;
+
 import static com.google.common.base.Preconditions.checkNotNull;
 
 /**

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/java/org/apache/aurora/scheduler/thrift/aop/APIVersionInterceptor.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/aurora/scheduler/thrift/aop/APIVersionInterceptor.java b/src/main/java/org/apache/aurora/scheduler/thrift/aop/APIVersionInterceptor.java
index d66a2b2..a19d805 100644
--- a/src/main/java/org/apache/aurora/scheduler/thrift/aop/APIVersionInterceptor.java
+++ b/src/main/java/org/apache/aurora/scheduler/thrift/aop/APIVersionInterceptor.java
@@ -1,11 +1,11 @@
-package com.twitter.aurora.scheduler.thrift.aop;
+package org.apache.aurora.scheduler.thrift.aop;
 
 import org.aopalliance.intercept.MethodInterceptor;
 import org.aopalliance.intercept.MethodInvocation;
 
-import com.twitter.aurora.gen.Response;
+import org.apache.aurora.gen.Response;
 
-import static com.twitter.aurora.gen.apiConstants.CURRENT_API_VERSION;
+import static org.apache.aurora.gen.apiConstants.CURRENT_API_VERSION;
 
 class APIVersionInterceptor implements MethodInterceptor {
 

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/java/org/apache/aurora/scheduler/thrift/aop/AopModule.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/aurora/scheduler/thrift/aop/AopModule.java b/src/main/java/org/apache/aurora/scheduler/thrift/aop/AopModule.java
index 4afc263..a953b40 100644
--- a/src/main/java/org/apache/aurora/scheduler/thrift/aop/AopModule.java
+++ b/src/main/java/org/apache/aurora/scheduler/thrift/aop/AopModule.java
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.twitter.aurora.scheduler.thrift.aop;
+package org.apache.aurora.scheduler.thrift.aop;
 
 import java.lang.reflect.Method;
 import java.util.List;
@@ -38,16 +38,17 @@ import com.google.inject.TypeLiteral;
 import com.google.inject.matcher.Matcher;
 import com.google.inject.matcher.Matchers;
 
-import org.aopalliance.intercept.MethodInterceptor;
-
-import com.twitter.aurora.GuiceUtils;
-import com.twitter.aurora.auth.CapabilityValidator;
-import com.twitter.aurora.gen.AuroraAdmin;
-import com.twitter.aurora.gen.AuroraSchedulerManager;
-import com.twitter.aurora.scheduler.thrift.auth.DecoratedThrift;
 import com.twitter.common.args.Arg;
 import com.twitter.common.args.CmdLine;
 
+import org.aopalliance.intercept.MethodInterceptor;
+
+import org.apache.aurora.GuiceUtils;
+import org.apache.aurora.auth.CapabilityValidator;
+import org.apache.aurora.gen.AuroraAdmin;
+import org.apache.aurora.gen.AuroraSchedulerManager;
+import org.apache.aurora.scheduler.thrift.auth.DecoratedThrift;
+
 /**
  * Binding module for AOP-style decorations of the thrift API.
  */

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/java/org/apache/aurora/scheduler/thrift/aop/FeatureToggleInterceptor.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/aurora/scheduler/thrift/aop/FeatureToggleInterceptor.java b/src/main/java/org/apache/aurora/scheduler/thrift/aop/FeatureToggleInterceptor.java
index 03c3d99..68e9642 100644
--- a/src/main/java/org/apache/aurora/scheduler/thrift/aop/FeatureToggleInterceptor.java
+++ b/src/main/java/org/apache/aurora/scheduler/thrift/aop/FeatureToggleInterceptor.java
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.twitter.aurora.scheduler.thrift.aop;
+package org.apache.aurora.scheduler.thrift.aop;
 
 import java.lang.reflect.Method;
 
@@ -24,7 +24,7 @@ import com.google.common.base.Predicate;
 import org.aopalliance.intercept.MethodInterceptor;
 import org.aopalliance.intercept.MethodInvocation;
 
-import com.twitter.aurora.gen.ResponseCode;
+import org.apache.aurora.gen.ResponseCode;
 
 /**
  * A method interceptor that blocks access to features based on a supplied predicate.

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/java/org/apache/aurora/scheduler/thrift/aop/Interceptors.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/aurora/scheduler/thrift/aop/Interceptors.java b/src/main/java/org/apache/aurora/scheduler/thrift/aop/Interceptors.java
index d0cb9c1..4f3b705 100644
--- a/src/main/java/org/apache/aurora/scheduler/thrift/aop/Interceptors.java
+++ b/src/main/java/org/apache/aurora/scheduler/thrift/aop/Interceptors.java
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.twitter.aurora.scheduler.thrift.aop;
+package org.apache.aurora.scheduler.thrift.aop;
 
 import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
@@ -21,7 +21,7 @@ import java.util.logging.Logger;
 
 import com.google.common.base.Throwables;
 
-import com.twitter.aurora.gen.ResponseCode;
+import org.apache.aurora.gen.ResponseCode;
 
 /**
  * Utility class for functions useful when implementing an interceptor on the thrift interface.

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/java/org/apache/aurora/scheduler/thrift/aop/LoggingInterceptor.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/aurora/scheduler/thrift/aop/LoggingInterceptor.java b/src/main/java/org/apache/aurora/scheduler/thrift/aop/LoggingInterceptor.java
index 5f773cc..93486aa 100644
--- a/src/main/java/org/apache/aurora/scheduler/thrift/aop/LoggingInterceptor.java
+++ b/src/main/java/org/apache/aurora/scheduler/thrift/aop/LoggingInterceptor.java
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.twitter.aurora.scheduler.thrift.aop;
+package org.apache.aurora.scheduler.thrift.aop;
 
 import java.util.List;
 import java.util.Map;
@@ -30,13 +30,13 @@ import com.google.common.collect.Lists;
 import org.aopalliance.intercept.MethodInterceptor;
 import org.aopalliance.intercept.MethodInvocation;
 
-import com.twitter.aurora.auth.CapabilityValidator;
-import com.twitter.aurora.gen.ExecutorConfig;
-import com.twitter.aurora.gen.JobConfiguration;
-import com.twitter.aurora.gen.ResponseCode;
-import com.twitter.aurora.gen.SessionKey;
+import org.apache.aurora.auth.CapabilityValidator;
+import org.apache.aurora.gen.ExecutorConfig;
+import org.apache.aurora.gen.JobConfiguration;
+import org.apache.aurora.gen.ResponseCode;
+import org.apache.aurora.gen.SessionKey;
 
-import static com.twitter.aurora.scheduler.thrift.aop.Interceptors.properlyTypedResponse;
+import static org.apache.aurora.scheduler.thrift.aop.Interceptors.properlyTypedResponse;
 
 /**
  * A method interceptor that logs all invocations as well as any unchecked exceptions thrown from

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/java/org/apache/aurora/scheduler/thrift/aop/ThriftStatsExporterInterceptor.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/aurora/scheduler/thrift/aop/ThriftStatsExporterInterceptor.java b/src/main/java/org/apache/aurora/scheduler/thrift/aop/ThriftStatsExporterInterceptor.java
index d700ab5..c86cd08 100644
--- a/src/main/java/org/apache/aurora/scheduler/thrift/aop/ThriftStatsExporterInterceptor.java
+++ b/src/main/java/org/apache/aurora/scheduler/thrift/aop/ThriftStatsExporterInterceptor.java
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.twitter.aurora.scheduler.thrift.aop;
+package org.apache.aurora.scheduler.thrift.aop;
 
 import java.lang.reflect.Method;
 
@@ -21,12 +21,12 @@ import com.google.common.cache.CacheBuilder;
 import com.google.common.cache.CacheLoader;
 import com.google.common.cache.LoadingCache;
 
-import org.aopalliance.intercept.MethodInterceptor;
-import org.aopalliance.intercept.MethodInvocation;
-
 import com.twitter.common.stats.SlidingStats;
 import com.twitter.common.stats.Stats;
 
+import org.aopalliance.intercept.MethodInterceptor;
+import org.aopalliance.intercept.MethodInvocation;
+
 /**
  * A method interceptor that exports counterStats about thrift calls.
  */

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/java/org/apache/aurora/scheduler/thrift/aop/UserCapabilityInterceptor.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/aurora/scheduler/thrift/aop/UserCapabilityInterceptor.java b/src/main/java/org/apache/aurora/scheduler/thrift/aop/UserCapabilityInterceptor.java
index d9240bc..9090e00 100644
--- a/src/main/java/org/apache/aurora/scheduler/thrift/aop/UserCapabilityInterceptor.java
+++ b/src/main/java/org/apache/aurora/scheduler/thrift/aop/UserCapabilityInterceptor.java
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.twitter.aurora.scheduler.thrift.aop;
+package org.apache.aurora.scheduler.thrift.aop;
 
 import java.lang.reflect.Method;
 import java.util.Arrays;
@@ -32,13 +32,13 @@ import com.google.common.collect.ImmutableList;
 import org.aopalliance.intercept.MethodInterceptor;
 import org.aopalliance.intercept.MethodInvocation;
 
-import com.twitter.aurora.auth.CapabilityValidator;
-import com.twitter.aurora.auth.CapabilityValidator.AuditCheck;
-import com.twitter.aurora.auth.CapabilityValidator.Capability;
-import com.twitter.aurora.auth.SessionValidator.AuthFailedException;
-import com.twitter.aurora.gen.ResponseCode;
-import com.twitter.aurora.gen.SessionKey;
-import com.twitter.aurora.scheduler.thrift.auth.Requires;
+import org.apache.aurora.auth.CapabilityValidator;
+import org.apache.aurora.auth.CapabilityValidator.AuditCheck;
+import org.apache.aurora.auth.CapabilityValidator.Capability;
+import org.apache.aurora.auth.SessionValidator.AuthFailedException;
+import org.apache.aurora.gen.ResponseCode;
+import org.apache.aurora.gen.SessionKey;
+import org.apache.aurora.scheduler.thrift.auth.Requires;
 
 /**
  * A method interceptor that will authenticate users identified by a {@link SessionKey} argument

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/java/org/apache/aurora/scheduler/thrift/auth/DecoratedThrift.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/aurora/scheduler/thrift/auth/DecoratedThrift.java b/src/main/java/org/apache/aurora/scheduler/thrift/auth/DecoratedThrift.java
index 4a667c5..a17127b 100644
--- a/src/main/java/org/apache/aurora/scheduler/thrift/auth/DecoratedThrift.java
+++ b/src/main/java/org/apache/aurora/scheduler/thrift/auth/DecoratedThrift.java
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.twitter.aurora.scheduler.thrift.auth;
+package org.apache.aurora.scheduler.thrift.auth;
 
 import java.lang.annotation.Retention;
 import java.lang.annotation.Target;

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/java/org/apache/aurora/scheduler/thrift/auth/Requires.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/aurora/scheduler/thrift/auth/Requires.java b/src/main/java/org/apache/aurora/scheduler/thrift/auth/Requires.java
index 0fff3f6..766e874 100644
--- a/src/main/java/org/apache/aurora/scheduler/thrift/auth/Requires.java
+++ b/src/main/java/org/apache/aurora/scheduler/thrift/auth/Requires.java
@@ -13,12 +13,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.twitter.aurora.scheduler.thrift.auth;
+package org.apache.aurora.scheduler.thrift.auth;
 
 import java.lang.annotation.Retention;
 import java.lang.annotation.Target;
 
-import com.twitter.aurora.auth.CapabilityValidator.Capability;
+import org.apache.aurora.auth.CapabilityValidator.Capability;
 
 import static java.lang.annotation.ElementType.METHOD;
 import static java.lang.annotation.RetentionPolicy.RUNTIME;

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/java/org/apache/aurora/scheduler/thrift/auth/ThriftAuthModule.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/aurora/scheduler/thrift/auth/ThriftAuthModule.java b/src/main/java/org/apache/aurora/scheduler/thrift/auth/ThriftAuthModule.java
index 66f9033..e0a16dd 100644
--- a/src/main/java/org/apache/aurora/scheduler/thrift/auth/ThriftAuthModule.java
+++ b/src/main/java/org/apache/aurora/scheduler/thrift/auth/ThriftAuthModule.java
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.twitter.aurora.scheduler.thrift.auth;
+package org.apache.aurora.scheduler.thrift.auth;
 
 import java.util.Map;
 
@@ -23,13 +23,14 @@ import com.google.common.collect.ImmutableMap;
 import com.google.inject.AbstractModule;
 import com.google.inject.TypeLiteral;
 
-import com.twitter.aurora.auth.CapabilityValidator;
-import com.twitter.aurora.auth.CapabilityValidator.Capability;
-import com.twitter.aurora.auth.SessionValidator;
 import com.twitter.common.args.Arg;
 import com.twitter.common.args.CmdLine;
 import com.twitter.common.args.constraints.NotEmpty;
 
+import org.apache.aurora.auth.CapabilityValidator;
+import org.apache.aurora.auth.CapabilityValidator.Capability;
+import org.apache.aurora.auth.SessionValidator;
+
 /**
  * Binding module for authentication of users with special capabilities for admin functions.
  */

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/admin/BUILD
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/admin/BUILD b/src/main/python/apache/aurora/admin/BUILD
index c8089b4..8560990 100644
--- a/src/main/python/apache/aurora/admin/BUILD
+++ b/src/main/python/apache/aurora/admin/BUILD
@@ -4,8 +4,8 @@ python_library(
   dependencies = [
     pants('aurora/twitterdeps/src/python/twitter/common/log'),
     pants('aurora/twitterdeps/src/python/twitter/common/quantity'),
-    pants('src/main/python/twitter/aurora/client:api'),
-    pants('src/main/python/twitter/aurora/client:base'),
-    pants('src/main/thrift/com/twitter/aurora/gen:py-thrift'),
+    pants('src/main/python/apache/aurora/client:api'),
+    pants('src/main/python/apache/aurora/client:base'),
+    pants('src/main/thrift/org/apache/aurora/gen:py-thrift'),
   ]
 )

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/admin/mesos_maintenance.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/admin/mesos_maintenance.py b/src/main/python/apache/aurora/admin/mesos_maintenance.py
index 4e14436..c2c251c 100644
--- a/src/main/python/apache/aurora/admin/mesos_maintenance.py
+++ b/src/main/python/apache/aurora/admin/mesos_maintenance.py
@@ -4,10 +4,10 @@ import time
 from twitter.common import log
 from twitter.common.quantity import Amount, Time
 
-from twitter.aurora.client.api import AuroraClientAPI
-from twitter.aurora.client.base import check_and_log_response
+from apache.aurora.client.api import AuroraClientAPI
+from apache.aurora.client.base import check_and_log_response
 
-from gen.twitter.aurora.ttypes import Hosts, MaintenanceMode
+from gen.apache.aurora.ttypes import Hosts, MaintenanceMode
 
 
 def group_by_host(hostname):

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/client/BUILD
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/client/BUILD b/src/main/python/apache/aurora/client/BUILD
index 70eef2e..5102970 100644
--- a/src/main/python/apache/aurora/client/BUILD
+++ b/src/main/python/apache/aurora/client/BUILD
@@ -4,7 +4,7 @@ import os
 python_library(
   name = 'api',
   dependencies = [
-    pants('src/main/python/twitter/aurora/client/api')
+    pants('src/main/python/apache/aurora/client/api')
   ]
 )
 
@@ -14,7 +14,7 @@ python_library(
   dependencies = [
     pants('aurora/twitterdeps/src/python/twitter/common/app'),
     pants('aurora/twitterdeps/src/python/twitter/common/log'),
-    pants('src/main/thrift/com/twitter/aurora/gen:py-thrift'),
+    pants('src/main/thrift/org/apache/aurora/gen:py-thrift'),
   ]
 )
 
@@ -30,13 +30,13 @@ python_library(
   name = 'config',
   sources = ['config.py'],
   dependencies = [
-    pants('src/main/python/twitter/aurora/BUILD.thirdparty:pystachio'),
+    pants('src/main/python/apache/aurora/BUILD.thirdparty:pystachio'),
     pants(':base'),
     pants(':binding_helper'),
     pants('aurora/twitterdeps/src/python/twitter/common/app'),
     pants('aurora/twitterdeps/src/python/twitter/common/log'),
-    pants('src/main/python/twitter/aurora/config'),
-    pants('src/main/thrift/com/twitter/aurora/gen:py-thrift'),
+    pants('src/main/python/apache/aurora/config'),
+    pants('src/main/thrift/org/apache/aurora/gen:py-thrift'),
   ]
 )
 
@@ -46,9 +46,9 @@ python_library(
   dependencies = [
     pants(':base'),
     pants('aurora/twitterdeps/src/python/twitter/common/app'),
-    pants('src/main/python/twitter/aurora/client/hooks'),
-    pants('src/main/python/twitter/aurora/common:cluster'),
-    pants('src/main/python/twitter/aurora/common:clusters'),
+    pants('src/main/python/apache/aurora/client/hooks'),
+    pants('src/main/python/apache/aurora/common:cluster'),
+    pants('src/main/python/apache/aurora/common:clusters'),
   ]
 )
 
@@ -56,23 +56,23 @@ python_library(
   name = 'options',
   sources = ['options.py'],
   dependencies = [
-    pants('src/main/python/twitter/thermos/common:options'),
-    pants('src/main/python/twitter/aurora/common:aurora_job_key'),
+    pants('src/main/python/apache/thermos/common:options'),
+    pants('src/main/python/apache/aurora/common:aurora_job_key'),
   ]
 )
 
 python_library(
   name = 'client-packaged',
   dependencies = [
-    pants('src/main/python/twitter/aurora/common'),
-    pants('src/main/python/twitter/aurora/config'),
-    pants('src/main/python/twitter/thermos/common'),
+    pants('src/main/python/apache/aurora/common'),
+    pants('src/main/python/apache/aurora/config'),
+    pants('src/main/python/apache/thermos/common'),
   ],
   provides = setup_py(
-    name = 'twitter.aurora.client',
+    name = 'apache.aurora.client',
     version = open(os.path.join(get_buildroot(), '.auroraversion')).read().strip().lower(),
   ).with_binaries(
-    aurora_admin = pants('src/main/python/twitter/aurora/client/bin:aurora_admin'),
-    aurora_client = pants('src/main/python/twitter/aurora/client/bin:aurora_client'),
+    aurora_admin = pants('src/main/python/apache/aurora/client/bin:aurora_admin'),
+    aurora_client = pants('src/main/python/apache/aurora/client/bin:aurora_client'),
   )
 )

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/client/api/BUILD
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/client/api/BUILD b/src/main/python/apache/aurora/client/api/BUILD
index 4935b8a..9af74e9 100644
--- a/src/main/python/apache/aurora/client/api/BUILD
+++ b/src/main/python/apache/aurora/client/api/BUILD
@@ -7,8 +7,8 @@ python_library(
     pants(':updater'),
     pants('aurora/twitterdeps/src/python/twitter/common/lang'),
     pants('aurora/twitterdeps/src/python/twitter/common/log'),
-    pants('src/main/python/twitter/aurora/common'),
-    pants('src/main/thrift/com/twitter/aurora/gen:py-thrift'),
+    pants('src/main/python/apache/aurora/common'),
+    pants('src/main/thrift/org/apache/aurora/gen:py-thrift'),
   ]
 )
 
@@ -16,12 +16,12 @@ python_library(
   name = 'command_runner',
   sources = ['command_runner.py'],
   dependencies = [
-    pants('src/main/python/twitter/aurora/BUILD.thirdparty:pystachio'),
+    pants('src/main/python/apache/aurora/BUILD.thirdparty:pystachio'),
     pants(':api'),
-    pants('src/main/python/twitter/thermos/config:schema'),
-    pants('src/main/python/twitter/aurora/common:cluster'),
-    pants('src/main/python/twitter/aurora/config:schema'),
-    pants('src/main/thrift/com/twitter/aurora/gen:py-thrift'),
+    pants('src/main/python/apache/thermos/config:schema'),
+    pants('src/main/python/apache/aurora/common:cluster'),
+    pants('src/main/python/apache/aurora/config:schema'),
+    pants('src/main/thrift/org/apache/aurora/gen:py-thrift'),
   ]
 )
 
@@ -31,8 +31,8 @@ python_library(
   dependencies = [
     pants(':api'),
     pants('aurora/twitterdeps/src/python/twitter/common/log'),
-    pants('src/main/python/twitter/aurora/client:base'),
-    pants('src/main/python/twitter/aurora/common'),
+    pants('src/main/python/apache/aurora/client:base'),
+    pants('src/main/python/apache/aurora/common'),
   ]
 )
 
@@ -41,7 +41,7 @@ python_library(
   sources = ['job_monitor.py'],
   dependencies = [
     pants('aurora/twitterdeps/src/python/twitter/common/quantity'),
-    pants('src/main/thrift/com/twitter/aurora/gen:py-thrift'),
+    pants('src/main/thrift/org/apache/aurora/gen:py-thrift'),
   ]
 )
 
@@ -52,7 +52,7 @@ python_library(
     pants(':instance_watcher'),
     pants(':updater_util'),
     pants('aurora/twitterdeps/src/python/twitter/common/log'),
-    pants('src/main/thrift/com/twitter/aurora/gen:py-thrift'),
+    pants('src/main/thrift/org/apache/aurora/gen:py-thrift'),
   ]
 )
 
@@ -65,9 +65,9 @@ python_library(
     pants('aurora/twitterdeps/src/python/twitter/common/rpc/transports:tsslsocket'),
     pants('aurora/twitterdeps/src/python/twitter/common/zookeeper/serverset:kazoo_serverset'),
     pants('aurora/twitterdeps/src/python/twitter/common/zookeeper:kazoo_client'),
-    pants('src/main/python/twitter/aurora/common/auth'),
-    pants('src/main/python/twitter/aurora/common:cluster'),
-    pants('src/main/thrift/com/twitter/aurora/gen:py-thrift'),
+    pants('src/main/python/apache/aurora/common/auth'),
+    pants('src/main/python/apache/aurora/common:cluster'),
+    pants('src/main/thrift/org/apache/aurora/gen:py-thrift'),
   ]
 )
 
@@ -78,8 +78,8 @@ python_library(
     pants(':scheduler_client'),
     pants('aurora/twitterdeps/src/python/twitter/common/lang'),
     pants('aurora/twitterdeps/src/python/twitter/common/log'),
-    pants('src/main/python/twitter/aurora/common:http_signaler'),
-    pants('src/main/thrift/com/twitter/aurora/gen:py-thrift'),
+    pants('src/main/python/apache/aurora/common:http_signaler'),
+    pants('src/main/thrift/org/apache/aurora/gen:py-thrift'),
   ]
 )
 
@@ -91,7 +91,7 @@ python_library(
     pants(':instance_watcher'),
     pants(':updater_util'),
     pants('aurora/twitterdeps/src/python/twitter/common/log'),
-    pants('src/main/thrift/com/twitter/aurora/gen:py-thrift'),
+    pants('src/main/thrift/org/apache/aurora/gen:py-thrift'),
   ]
 )
 

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/client/api/__init__.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/client/api/__init__.py b/src/main/python/apache/aurora/client/api/__init__.py
index 60f4011..09a646b 100644
--- a/src/main/python/apache/aurora/client/api/__init__.py
+++ b/src/main/python/apache/aurora/client/api/__init__.py
@@ -1,11 +1,11 @@
 from twitter.common import log
 
-from twitter.aurora.common.aurora_job_key import AuroraJobKey
-from twitter.aurora.common.auth import make_session_key
-from twitter.aurora.common.cluster import Cluster
+from apache.aurora.common.aurora_job_key import AuroraJobKey
+from apache.aurora.common.auth import make_session_key
+from apache.aurora.common.cluster import Cluster
 
-from gen.twitter.aurora.constants import LIVE_STATES
-from gen.twitter.aurora.ttypes import (
+from gen.apache.aurora.constants import LIVE_STATES
+from gen.apache.aurora.ttypes import (
     Response,
     Identity,
     Quota,

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/client/api/command_runner.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/client/api/command_runner.py b/src/main/python/apache/aurora/client/api/command_runner.py
index 0a8ad33..dda7424 100644
--- a/src/main/python/apache/aurora/client/api/command_runner.py
+++ b/src/main/python/apache/aurora/client/api/command_runner.py
@@ -4,13 +4,13 @@ import subprocess
 
 from twitter.common import log
 
-from twitter.aurora.client.api import AuroraClientAPI
-from twitter.aurora.config.schema.base import MesosContext
-from twitter.aurora.common.cluster import Cluster
-from twitter.thermos.config.schema import ThermosContext
+from apache.aurora.client.api import AuroraClientAPI
+from apache.aurora.config.schema.base import MesosContext
+from apache.aurora.common.cluster import Cluster
+from apache.thermos.config.schema import ThermosContext
 
-from gen.twitter.aurora.constants import LIVE_STATES
-from gen.twitter.aurora.ttypes import (
+from gen.apache.aurora.constants import LIVE_STATES
+from gen.apache.aurora.ttypes import (
   Identity,
   ResponseCode,
   TaskQuery)

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/client/api/disambiguator.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/client/api/disambiguator.py b/src/main/python/apache/aurora/client/api/disambiguator.py
index 4693574..c3241de 100644
--- a/src/main/python/apache/aurora/client/api/disambiguator.py
+++ b/src/main/python/apache/aurora/client/api/disambiguator.py
@@ -1,8 +1,8 @@
 from twitter.common import log
 
-from twitter.aurora.client.api import AuroraClientAPI
-from twitter.aurora.client.base import check_and_log_response, deprecation_warning, die
-from twitter.aurora.common.aurora_job_key import AuroraJobKey
+from apache.aurora.client.api import AuroraClientAPI
+from apache.aurora.client.base import check_and_log_response, deprecation_warning, die
+from apache.aurora.common.aurora_job_key import AuroraJobKey
 
 
 class LiveJobDisambiguator(object):

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/client/api/health_check.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/client/api/health_check.py b/src/main/python/apache/aurora/client/api/health_check.py
index b75ee6e..20a7cb1 100644
--- a/src/main/python/apache/aurora/client/api/health_check.py
+++ b/src/main/python/apache/aurora/client/api/health_check.py
@@ -3,9 +3,9 @@ from abc import abstractmethod
 from twitter.common import log
 from twitter.common.lang import Interface
 
-from twitter.aurora.common.http_signaler import HttpSignaler
+from apache.aurora.common.http_signaler import HttpSignaler
 
-from gen.twitter.aurora.ttypes import ScheduleStatus
+from gen.apache.aurora.ttypes import ScheduleStatus
 
 
 class HealthCheck(Interface):

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/client/api/instance_watcher.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/client/api/instance_watcher.py b/src/main/python/apache/aurora/client/api/instance_watcher.py
index 5c69487..4043948 100644
--- a/src/main/python/apache/aurora/client/api/instance_watcher.py
+++ b/src/main/python/apache/aurora/client/api/instance_watcher.py
@@ -3,7 +3,7 @@ import time
 from twitter.common import log
 from .health_check import InstanceWatcherHealthCheck
 
-from gen.twitter.aurora.ttypes import (
+from gen.apache.aurora.ttypes import (
   Identity,
   ResponseCode,
   ScheduleStatus,

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/client/api/job_monitor.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/client/api/job_monitor.py b/src/main/python/apache/aurora/client/api/job_monitor.py
index 45edd1a..f444d1e 100644
--- a/src/main/python/apache/aurora/client/api/job_monitor.py
+++ b/src/main/python/apache/aurora/client/api/job_monitor.py
@@ -2,11 +2,11 @@ import time
 
 from twitter.common.quantity import Amount, Time
 
-from gen.twitter.aurora.constants import (
+from gen.apache.aurora.constants import (
     LIVE_STATES,
     TERMINAL_STATES
 )
-from gen.twitter.aurora.ttypes import (
+from gen.apache.aurora.ttypes import (
     Identity,
     TaskQuery
 )

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/client/api/restarter.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/client/api/restarter.py b/src/main/python/apache/aurora/client/api/restarter.py
index bf196e1..bd62a60 100644
--- a/src/main/python/apache/aurora/client/api/restarter.py
+++ b/src/main/python/apache/aurora/client/api/restarter.py
@@ -1,7 +1,7 @@
 from twitter.common import log
 
-from gen.twitter.aurora.constants import ACTIVE_STATES
-from gen.twitter.aurora.ttypes import ResponseCode
+from gen.apache.aurora.constants import ACTIVE_STATES
+from gen.apache.aurora.ttypes import ResponseCode
 
 from .instance_watcher import InstanceWatcher
 from .updater_util import FailureThreshold

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/client/api/scheduler_client.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/client/api/scheduler_client.py b/src/main/python/apache/aurora/client/api/scheduler_client.py
index ffec604..1b38f7b 100644
--- a/src/main/python/apache/aurora/client/api/scheduler_client.py
+++ b/src/main/python/apache/aurora/client/api/scheduler_client.py
@@ -2,16 +2,16 @@ import functools
 import threading
 import time
 
-from twitter.aurora.common.auth import make_session_key, SessionKeyError
-from twitter.aurora.common.cluster import Cluster
+from apache.aurora.common.auth import make_session_key, SessionKeyError
+from apache.aurora.common.cluster import Cluster
 from twitter.common import log
 from twitter.common.quantity import Amount, Time
 from twitter.common.rpc.transports.tsslsocket import DelayedHandshakeTSSLSocket
 from twitter.common.zookeeper.kazoo_client import TwitterKazooClient
 from twitter.common.zookeeper.serverset import ServerSet
 
-from gen.twitter.aurora import AuroraAdmin
-from gen.twitter.aurora.constants import CURRENT_API_VERSION
+from gen.apache.aurora import AuroraAdmin
+from gen.apache.aurora.constants import CURRENT_API_VERSION
 
 from thrift.protocol import TBinaryProtocol
 from thrift.transport import TSocket, TTransport

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/client/api/updater.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/client/api/updater.py b/src/main/python/apache/aurora/client/api/updater.py
index 6e8e8a9..e364f26 100644
--- a/src/main/python/apache/aurora/client/api/updater.py
+++ b/src/main/python/apache/aurora/client/api/updater.py
@@ -3,9 +3,9 @@ from difflib import unified_diff
 
 from twitter.common import log
 
-from gen.twitter.aurora.constants import ACTIVE_STATES
+from gen.apache.aurora.constants import ACTIVE_STATES
 
-from gen.twitter.aurora.ttypes import (
+from gen.apache.aurora.ttypes import (
     AddInstancesConfig,
     JobConfigValidation,
     JobKey,

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/client/base.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/client/base.py b/src/main/python/apache/aurora/client/base.py
index 0936743..ed5737d 100644
--- a/src/main/python/apache/aurora/client/base.py
+++ b/src/main/python/apache/aurora/client/base.py
@@ -5,7 +5,7 @@ from urlparse import urljoin
 
 from twitter.common import app, log
 
-from gen.twitter.aurora.ttypes import ResponseCode
+from gen.apache.aurora.ttypes import ResponseCode
 
 LOCKED_WARNING = """
 Note: if the scheduler detects that a job update is in progress (or was not

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/client/bin/BUILD
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/client/bin/BUILD b/src/main/python/apache/aurora/client/bin/BUILD
index 7802245..4561155 100644
--- a/src/main/python/apache/aurora/client/bin/BUILD
+++ b/src/main/python/apache/aurora/client/bin/BUILD
@@ -1,25 +1,25 @@
 python_binary(
   name = 'aurora_client',
   source = 'aurora_client.py',
-  entry_point = 'twitter.aurora.client.bin.aurora_client:proxy_main',
+  entry_point = 'apache.aurora.client.bin.aurora_client:proxy_main',
   dependencies = [
     pants('aurora/twitterdeps/src/python/twitter/common/app'),
     pants('aurora/twitterdeps/src/python/twitter/common/log'),
-    pants('src/main/python/twitter/aurora/client/commands:all'),
-    pants('src/main/python/twitter/aurora/client:base'),
+    pants('src/main/python/apache/aurora/client/commands:all'),
+    pants('src/main/python/apache/aurora/client:base'),
   ]
 )
 
 python_binary(
   name = 'aurora_admin',
   source = 'aurora_admin.py',
-  entry_point = 'twitter.aurora.client.bin.aurora_admin:proxy_main',
+  entry_point = 'apache.aurora.client.bin.aurora_admin:proxy_main',
   dependencies = [
     pants('aurora/twitterdeps/src/python/twitter/common/app'),
     pants('aurora/twitterdeps/src/python/twitter/common/log'),
-    pants('src/main/python/twitter/aurora/client/commands:admin'),
-    pants('src/main/python/twitter/aurora/client/commands:help'),
-    pants('src/main/python/twitter/aurora/client:base'),
-    pants('src/main/python/twitter/aurora/client:options'),
+    pants('src/main/python/apache/aurora/client/commands:admin'),
+    pants('src/main/python/apache/aurora/client/commands:help'),
+    pants('src/main/python/apache/aurora/client:base'),
+    pants('src/main/python/apache/aurora/client:options'),
   ]
 )

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/python/apache/aurora/client/bin/aurora_admin.py
----------------------------------------------------------------------
diff --git a/src/main/python/apache/aurora/client/bin/aurora_admin.py b/src/main/python/apache/aurora/client/bin/aurora_admin.py
index 53fd882..7b59bbd 100644
--- a/src/main/python/apache/aurora/client/bin/aurora_admin.py
+++ b/src/main/python/apache/aurora/client/bin/aurora_admin.py
@@ -1,6 +1,6 @@
-from twitter.aurora.client.base import generate_terse_usage
-from twitter.aurora.client.commands import admin, help
-from twitter.aurora.client.options import add_verbosity_options
+from apache.aurora.client.base import generate_terse_usage
+from apache.aurora.client.commands import admin, help
+from apache.aurora.client.options import add_verbosity_options
 from twitter.common import app
 from twitter.common.log.options import LogOptions
diff --git a/src/main/java/org/apache/aurora/scheduler/storage/mem/MemStorageModule.java b/src/main/java/org/apache/aurora/scheduler/storage/mem/MemStorageModule.java
index a99aa12..1e36a86 100644
--- a/src/main/java/org/apache/aurora/scheduler/storage/mem/MemStorageModule.java
+++ b/src/main/java/org/apache/aurora/scheduler/storage/mem/MemStorageModule.java
@@ -13,23 +13,24 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.twitter.aurora.scheduler.storage.mem;
+package org.apache.aurora.scheduler.storage.mem;
 
 import javax.inject.Singleton;
 
 import com.google.inject.Key;
 import com.google.inject.PrivateModule;
 
-import com.twitter.aurora.scheduler.storage.AttributeStore;
-import com.twitter.aurora.scheduler.storage.JobStore;
-import com.twitter.aurora.scheduler.storage.LockStore;
-import com.twitter.aurora.scheduler.storage.QuotaStore;
-import com.twitter.aurora.scheduler.storage.SchedulerStore;
-import com.twitter.aurora.scheduler.storage.Storage;
-import com.twitter.aurora.scheduler.storage.Storage.Volatile;
-import com.twitter.aurora.scheduler.storage.TaskStore;
 import com.twitter.common.inject.Bindings.KeyFactory;
 
+import org.apache.aurora.scheduler.storage.AttributeStore;
+import org.apache.aurora.scheduler.storage.JobStore;
+import org.apache.aurora.scheduler.storage.LockStore;
+import org.apache.aurora.scheduler.storage.QuotaStore;
+import org.apache.aurora.scheduler.storage.SchedulerStore;
+import org.apache.aurora.scheduler.storage.Storage;
+import org.apache.aurora.scheduler.storage.Storage.Volatile;
+import org.apache.aurora.scheduler.storage.TaskStore;
+
 import static com.google.common.base.Preconditions.checkNotNull;
 
 /**
@@ -37,15 +38,15 @@ import static com.google.common.base.Preconditions.checkNotNull;
  * <p>
  * Exposes bindings for storage components:
  * <ul>
- *   <li>{@link com.twitter.aurora.scheduler.storage.Storage}</li>
+ *   <li>{@link org.apache.aurora.scheduler.storage.Storage}</li>
  *   <li>Keyed with keys provided by the provided{@code keyFactory}:</li>
  *     <ul>
  *       <li>{@link com.twitter.aurora.scheduler.storage.SchedulerStore}</li>
  *       <li>{@link com.twitter.aurora.scheduler.storage.JobStore}</li>
  *       <li>{@link com.twitter.aurora.scheduler.storage.TaskStore}</li>
  *       <li>{@link com.twitter.aurora.scheduler.storage.LockStore}</li>
  *       <li>{@link com.twitter.aurora.scheduler.storage.QuotaStore}</li>
  *       <li>{@link com.twitter.aurora.scheduler.storage.AttributeStore}</li>
  *     </ul>
  * </ul>
  */

http://git-wip-us.apache.org/repos/asf/incubator-aurora/blob/cfb13f65/src/main/java/org/apache/aurora/scheduler/storage/mem/MemTaskStore.java
----------------------------------------------------------------------
@@ -37,15 +38,15 @@ import static com.google.common.base.Preconditions.checkNotNull;
  *   <li>Keyed with keys provided by the provided{@code keyFactory}:</li>
  *     <ul>
- *       <li>{@link com.twitter.aurora.scheduler.storage.SchedulerStore}</li>
- *       <li>{@link com.twitter.aurora.scheduler.storage.JobStore}</li>
- *       <li>{@link com.twitter.aurora.scheduler.storage.TaskStore}</li>
- *       <li>{@link com.twitter.aurora.scheduler.storage.LockStore}</li>
- *       <li>{@link com.twitter.aurora.scheduler.storage.QuotaStore}</li>
- *       <li>{@link com.twitter.aurora.scheduler.storage.AttributeStore}</li>
+ *       <li>{@link org.apache.aurora.scheduler.storage.SchedulerStore}</li>
+ *       <li>{@link org.apache.aurora.scheduler.storage.JobStore}</li>
+ *       <li>{@link org.apache.aurora.scheduler.storage.TaskStore}</li>
+ *       <li>{@link org.apache.aurora.scheduler.storage.LockStore}</li>
+ *       <li>{@link org.apache.aurora.scheduler.storage.QuotaStore}</li>
+ *       <li>{@link org.apache.aurora.scheduler.storage.AttributeStore}</li>
  *     </ul>
  * </ul>